summaryrefslogtreecommitdiffstats
path: root/kword/KWCommand.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWCommand.cpp')
-rw-r--r--kword/KWCommand.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kword/KWCommand.cpp b/kword/KWCommand.cpp
index 20a4c918..47fda3e6 100644
--- a/kword/KWCommand.cpp
+++ b/kword/KWCommand.cpp
@@ -145,14 +145,14 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
break;
}
TQDomElement paragElem = *it;
// First line (if appending to non-empty line) : apply offset to formatting, don't apply parag layout
if ( item == 0 && m_idx > 0 )
{
// First load the default format, but only apply it to our new chars
- TQDomElement layout = paragElem.namedItem( "LAYOUT" ).toElement();
- if ( !layout.isNull() )
+ TQDomElement tqlayout = paragElem.namedItem( "LAYOUT" ).toElement();
+ if ( !tqlayout.isNull() )
{
- TQDomElement formatElem = layout.namedItem( "FORMAT" ).toElement();
+ TQDomElement formatElem = tqlayout.namedItem( "FORMAT" ).toElement();
if ( !formatElem.isNull() )
{
KoTextFormat f = parag->loadFormat( formatElem, 0L, TQFont(), KGlobal::locale()->language(),false );
@@ -167,7 +167,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
}
else
{
- if ( item == 0 ) // This paragraph existed, store its parag layout
+ if ( item == 0 ) // This paragraph existed, store its parag tqlayout
{
delete m_oldParagLayout;
m_oldParagLayout = new KoParagLayout( parag->paragLayout() );
@@ -179,7 +179,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
parag->setFormat( 0, len, parag->paragFormat(), TRUE );
parag->loadFormatting( paragElem, 0, (textFs->isMainFrameset()) );
}
- parag->invalidate(0); // the formatting will be done by caller (either KWTextFrameSet::pasteOasis or KoTextObject::undo/redo)
+ parag->tqinvalidate(0); // the formatting will be done by caller (either KWTextFrameSet::pasteOasis or KoTextObject::undo/redo)
parag->setChanged( TRUE );
parag = static_cast<KWTextParag *>(parag->next());
//kdDebug() << "KWPasteTextCommand::execute going to next parag: " << parag << endl;
@@ -913,7 +913,7 @@ KWFrameMoveCommand::KWFrameMoveCommand( const TQString &name,
void KWFrameMoveCommand::execute()
{
- bool needRelayout = false;
+ bool needRetqlayout = false;
KWDocument * doc = 0L;
TQValueList<FrameMoveStruct>::Iterator moveIt = m_frameMove.begin();
TQValueList<FrameIndex>::Iterator tmp = m_indexFrame.begin();
@@ -925,13 +925,13 @@ void KWFrameMoveCommand::execute()
frame->moveTopLeft( (*moveIt).newPos );
frame->updateRulerHandles();
- needRelayout = needRelayout || ( frame->runAround() != KWFrame::RA_NO );
+ needRetqlayout = needRetqlayout || ( frame->runAround() != KWFrame::RA_NO );
}
if ( doc )
{
doc->updateAllFrames();
- if ( needRelayout )
- doc->layout();
+ if ( needRetqlayout )
+ doc->tqlayout();
doc->updateRulerFrameStartEnd();
doc->repaintAllViews();
@@ -940,7 +940,7 @@ void KWFrameMoveCommand::execute()
void KWFrameMoveCommand::unexecute()
{
- bool needRelayout = false;
+ bool needRetqlayout = false;
KWDocument * doc = 0L;
TQValueList<FrameMoveStruct>::Iterator moveIt = m_frameMove.begin();
TQValueList<FrameIndex>::Iterator tmp = m_indexFrame.begin();
@@ -952,14 +952,14 @@ void KWFrameMoveCommand::unexecute()
frame->moveTopLeft( (*moveIt).oldPos );
frame->updateRulerHandles();
- needRelayout = needRelayout || ( frame->runAround() != KWFrame::RA_NO );
+ needRetqlayout = needRetqlayout || ( frame->runAround() != KWFrame::RA_NO );
}
if ( doc )
{
doc->updateAllFrames();
- if ( needRelayout )
- doc->layout();
+ if ( needRetqlayout )
+ doc->tqlayout();
doc->updateRulerFrameStartEnd();
doc->repaintAllViews();
}
@@ -995,7 +995,7 @@ void KWFramePropertiesCommand::execute()
{
doc->frameChanged( frame );
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1016,7 +1016,7 @@ void KWFramePropertiesCommand::unexecute()
{
doc->frameChanged( frame );
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1226,7 +1226,7 @@ void KWDeleteTableCommand::execute()
doc->refreshDocStructure((int)Tables);
doc->updateAllFrames();
m_pTable->updateFrames(); // not in the doc list anymore, so the above call didn't do it!
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
@@ -1240,7 +1240,7 @@ void KWDeleteTableCommand::unexecute()
doc->addFrameSet(m_pTable);
doc->refreshDocStructure((int)Tables);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
doc->updateRulerFrameStartEnd();
}
@@ -1284,7 +1284,7 @@ void KWInsertColumnCommand::execute()
}
Q_ASSERT(m_pTable->boundingRect().right() <= m_maxRight);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
}
@@ -1300,7 +1300,7 @@ void KWInsertColumnCommand::unexecute()
m_pTable->resizeWidth(m_oldWidth);
}
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
}
@@ -1332,7 +1332,7 @@ void KWInsertRowCommand::execute()
m_pTable->insertNewRow(m_rowPos); //only happens the first time
}
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
}
@@ -1345,7 +1345,7 @@ void KWInsertRowCommand::unexecute()
m_pTable->deleteRow( m_rowPos, *m_rr);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
@@ -1372,7 +1372,7 @@ void KWRemoveRowCommand::execute()
m_pTable->deleteRow( m_rowPos, *m_rr);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
void KWRemoveRowCommand::unexecute()
@@ -1381,7 +1381,7 @@ void KWRemoveRowCommand::unexecute()
KWDocument * doc = m_pTable->kWordDocument();
m_pTable->reInsertRow(*m_rr);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
}
@@ -1407,7 +1407,7 @@ void KWRemoveColumnCommand::execute()
m_pTable->deleteColumn( m_colPos, *m_rc);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
void KWRemoveColumnCommand::unexecute()
@@ -1416,7 +1416,7 @@ void KWRemoveColumnCommand::unexecute()
KWDocument * doc = m_pTable->kWordDocument();
m_pTable->reInsertColumn(*m_rc);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
doc->repaintAllViews();
}
@@ -1441,7 +1441,7 @@ void KWSplitCellCommand::execute()
//kdDebug()<<"split Cell m_colBegin :"<<m_colBegin<<" m_colEnd :"<<m_colEnd<<" m_rowBegin :"<<m_rowBegin<<" m_colEnd :"<<m_colEnd<<endl;
m_pTable->splitCell(m_rowEnd, m_colEnd,m_colBegin,m_rowBegin,m_ListFrameSet);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
void KWSplitCellCommand::unexecute()
@@ -1478,7 +1478,7 @@ void KWSplitCellCommand::unexecute()
m_rowBegin+m_rowEnd-1+cell->rowSpan()-1);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
@@ -1507,7 +1507,7 @@ void KWJoinCellCommand::execute()
doc->terminateEditing(m_pTable);
m_pTable->joinCells(m_colBegin,m_rowBegin,m_colEnd,m_rowEnd);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
void KWJoinCellCommand::unexecute()
@@ -1517,7 +1517,7 @@ void KWJoinCellCommand::unexecute()
doc->terminateEditing(m_pTable);
m_pTable->splitCell(m_rowEnd-m_rowBegin+1, m_colEnd-m_colBegin+1,m_colBegin,m_rowBegin,m_ListFrameSet,m_copyFrame);
doc->updateAllFrames();
- doc->layout();
+ doc->tqlayout();
}
@@ -1746,7 +1746,7 @@ KWInsertRemovePageCommand::~KWInsertRemovePageCommand() {
TQString KWInsertRemovePageCommand::name() const
{
return m_cmd == Insert ? i18n("Insert Page") // problem with after/before page
- : i18n("Delete Page %1").arg(m_pgNum);
+ : i18n("Delete Page %1").tqarg(m_pgNum);
}
void KWInsertRemovePageCommand::execute() {
@@ -1977,7 +1977,7 @@ void KWChangeFootNoteParametersCommand::changeVariableParameter( FootNoteParamet
if ( m_var->numberingType()== KWFootNoteVariable::Manual)
{
m_var->resize();
- m_var->paragraph()->invalidate(0);
+ m_var->paragraph()->tqinvalidate(0);
m_var->paragraph()->setChanged( true );
}
@@ -1986,7 +1986,7 @@ void KWChangeFootNoteParametersCommand::changeVariableParameter( FootNoteParamet
if ( frameset)
frameset->renumberFootNotes();
- // Re-layout the footnote/endnote frame
+ // Re-tqlayout the footnote/endnote frame
KWFrame* footNoteFrame = m_var->frameSet()->frame( 0 );
int framePage = footNoteFrame->pageNumber();
m_doc->recalcFrames( framePage, -1 );
@@ -2061,14 +2061,14 @@ KWResizeColumnCommand::KWResizeColumnCommand( KWTableFrameSet *table, int col, d
void KWResizeColumnCommand::execute()
{
m_table->resizeColumn(m_col, m_newSize);
- m_table->kWordDocument()->layout();
+ m_table->kWordDocument()->tqlayout();
m_table->kWordDocument()->repaintAllViews();
}
void KWResizeColumnCommand::unexecute()
{
m_table->resizeColumn(m_col, m_oldSize);
- m_table->kWordDocument()->layout();
+ m_table->kWordDocument()->tqlayout();
m_table->kWordDocument()->repaintAllViews();
}
@@ -145,14 +145,14 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
}
TQDomElement paragElem = *it;
- // First line (if appending to non-empty line) : apply offset to formatting, don't apply parag layout
+ // First line (if appending to non-empty line) : apply offset to formatting, don't apply parag tqlayout
if ( item == 0 && m_idx > 0 )
{